@@ -2,8 +2,11 @@ package Alien::Base::ModuleBuild;
 
 use strict;
 use warnings;
-use 5.008001;
+
+our $VERSION = '1.02';
+
 use parent 'Module::Build';
+
 use Capture::Tiny 0.17 qw/capture tee/;
 use File::chdir;
 use File::Spec;
@@ -13,7 +16,7 @@ no warnings;
 use Archive::Extract;
 use warnings;
 use Sort::Versions;
-use List::Util qw( uniq any );
+use List::Util qw/uniq/;
 use ExtUtils::Installed;
 use File::Copy qw/move/;
 use Env qw( @PATH );
@@ -22,17 +25,15 @@ use Shell::Config::Generate;
 use File::Path qw/mkpath/;
 use Config;
 use Text::ParseWords qw( shellwords );
+
 use Alien::Base::PkgConfig;
 use Alien::Base::ModuleBuild::Cabinet;
 use Alien::Base::ModuleBuild::Repository;
+
 use Alien::Base::ModuleBuild::Repository::HTTP;
 use Alien::Base::ModuleBuild::Repository::FTP;
 use Alien::Base::ModuleBuild::Repository::Local;
 
-# ABSTRACT: A Module::Build subclass for building Alien:: modules and their libraries
-our $VERSION = '1.16_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-
 # setup protocol specific classes
 # Alien:: author can override these defaults using alien_repository_class property
 my %default_repository_class = (
@@ -47,37 +48,11 @@ our $Verbose;
 $Verbose = $ENV{ALIEN_VERBOSE} if defined $ENV{ALIEN_VERBOSE};
 
 our $Force;
+$Force = $ENV{ALIEN_FORCE} if defined $ENV{ALIEN_FORCE};
+$Force = 1 if defined $ENV{ALIEN_INSTALL_TYPE} && $ENV{ALIEN_INSTALL_TYPE} eq 'share';
+
 our $ForceSystem;
-_compute_force();
-
-sub _compute_force
-{
-  undef $Force;
-  undef $ForceSystem;
-
-  if(defined $ENV{ALIEN_INSTALL_TYPE})
-  {
-    if($ENV{ALIEN_INSTALL_TYPE} eq 'share')
-    {
-      $Force       = 1;
-      $ForceSystem = 0;
-    }
-    elsif($ENV{ALIEN_INSTALL_TYPE} eq 'system')
-    {
-      $Force       = 0;
-      $ForceSystem = 1;
-    }
-    else  # anything else, including 'default'
-    {
-      $Force       = 0;
-      $ForceSystem = 0;
-    }
-  }
-  elsif(defined $ENV{ALIEN_FORCE})
-  {
-    $Force = $ENV{ALIEN_FORCE};
-  }
-}
+$ForceSystem = 1 if defined $ENV{ALIEN_INSTALL_TYPE} && $ENV{ALIEN_INSTALL_TYPE} eq 'system';
 
 ################
 #  Parameters  #
@@ -94,12 +69,9 @@ __PACKAGE__->add_property('alien_ffi_name');
 # alien_temp_dir: folder name for download/build
 __PACKAGE__->add_property( alien_temp_dir => '_alien' );
 
-# alien_install_type: allow to override alien install type
-__PACKAGE__->add_property( alien_install_type => undef );
-
 # alien_share_dir: folder name for the "install" of the library
-# this is added (unshifted) to the @{share_dir->{dist}}
-# N.B. is reset during constructor to be full folder name
+# this is added (unshifted) to the @{share_dir->{dist}}  
+# N.B. is reset during constructor to be full folder name 
 __PACKAGE__->add_property('alien_share_dir' => '_share' );
 
 # alien_selection_method: name of method for selecting file: (todo: newest, manual)
@@ -107,21 +79,21 @@ __PACKAGE__->add_property('alien_share_dir' => '_share' );
 __PACKAGE__->add_property( alien_selection_method => 'newest' );
 
 # alien_build_commands: arrayref of commands for building
-__PACKAGE__->add_property(
-  alien_build_commands =>
+__PACKAGE__->add_property( 
+  alien_build_commands => 
   default => [ '%c --prefix=%s', 'make' ],
 );
 
 # alien_test_commands: arrayref of commands for testing the library
 # note that this might be better tacked onto the build-time commands
-__PACKAGE__->add_property(
-  alien_test_commands =>
+__PACKAGE__->add_property( 
+  alien_test_commands => 
   default => [ ],
 );
 
 # alien_build_commands: arrayref of commands for installing the library
-__PACKAGE__->add_property(
-  alien_install_commands =>
+__PACKAGE__->add_property( 
+  alien_install_commands => 
   default => [ 'make install' ],
 );
 
@@ -197,20 +169,11 @@ sub new {
   my %args = @_;
 
   # merge default and user-defined repository classes
-  $args{alien_repository_class}{$_} ||= $default_repository_class{$_}
+  $args{alien_repository_class}{$_} ||= $default_repository_class{$_} 
     for keys %default_repository_class;
 
   my $self = $class->SUPER::new(%args);
 
-  ## Recheck Force System
-  if(!defined($ENV{ALIEN_INSTALL_TYPE}) && !defined($ENV{ALIEN_FORCE}) && defined($self->alien_install_type)) {
-    if   ($self->alien_install_type eq 'share' ) { $Force = 1; $ForceSystem = 0; }
-    elsif($self->alien_install_type eq 'system') { $Force = 0; $ForceSystem = 1; }
-  }
-
-  $self->config_data("Force" => $Force);
-  $self->config_data("ForceSystem" => $ForceSystem);
-
   $self->alien_helper->{pkg_config} = 'Alien::Base::PkgConfig->pkg_config_command'
     unless defined $self->alien_helper->{pkg_config};
 
@@ -230,7 +193,7 @@ sub new {
   $self->config_data( 'inline_auto_include' => $self->alien_inline_auto_include );
 
   if($Force || !$self->alien_check_installed_version) {
-    if (any { /(?<!\%)\%c/ } map { ref($_) ? @{$_} : $_ } @{ $self->alien_build_commands }) {
+    if (grep /(?<!\%)\%c/, map { ref($_) ? @{$_} : $_ } @{ $self->alien_build_commands }) {
       $self->config_data( 'autoconf' => 1 );
     }
 
@@ -240,7 +203,7 @@ sub new {
     } else {
       $self->config_data( 'msys' => 0 );
     }
-
+  
     foreach my $tool (keys %{ $self->alien_bin_requires  }) {
       my $version = $self->alien_bin_requires->{$tool};
       if($tool eq 'Alien::CMake' && $version < 0.07) {
@@ -266,7 +229,7 @@ sub new {
   }
 
 
-  # force newest for all automated testing
+  # force newest for all automated testing 
   #TODO (this probably should be checked for "input needed" rather than blindly assigned)
   if ($ENV{AUTOMATED_TESTING}) {
     $self->alien_selection_method('newest');
@@ -274,7 +237,7 @@ sub new {
 
   $self->config_data( 'finished_installing' => 0 );
 
-  if(any { /(?<!\%)\%p/ } map { ref($_) ? @{$_} : $_ } @{ $self->alien_build_commands }) {
+  if(grep /(?<!\%)\%p/, map { ref($_) ? @{$_} : $_ } @{ $self->alien_build_commands }) {
     carp "%p is deprecated, See https://metacpan.org/pod/Alien::Base::ModuleBuild::API#p";
   }
 
@@ -307,7 +270,7 @@ sub alien_init_temp_dir {
     local $CWD = $share_dir;
     open my $fh, '>', 'README' or die "Could not open README for writing (in directory $share_dir)\n";
     print $fh <<'END';
-This README file is autogenerated by Alien::Base.
+This README file is autogenerated by Alien::Base. 
 
 Currently it exists for testing purposes, but it might eventually contain information about the file(s) installed.
 END
@@ -352,7 +315,7 @@ sub ACTION_code {
     $self->depends_on('alien_code');
     $self->SUPER::ACTION_code;
   }
-
+  
   my $module = $self->module_name;
   my $file   = File::Spec->catfile($self->blib, 'lib', split /::/, "$module\::Install::Files.pm");
   unless (-e $file) {
@@ -360,8 +323,6 @@ sub ACTION_code {
     open my $fh, '>', $file;
     print $fh <<EOF;
 package $module\::Install::Files;
-use strict;
-use warnings;
 require $module;
 sub Inline { shift; $module->Inline(\@_) }
 1;
@@ -376,7 +337,7 @@ sub Inline { shift; $module->Inline(\@_) }
 EOF
     close $fh;
   }
-
+  
   if($self->alien_arch) {
     my @parts = split /::/, $module;
     my $arch_dir = File::Spec->catdir($self->blib, 'arch', 'auto', @parts);
@@ -392,7 +353,7 @@ EOF
 sub process_share_dir_files {
   my $self = shift;
   $self->SUPER::process_share_dir_files(@_);
-
+  
   # copy the compiled files into blib if running under blib scheme
   $self->depends_on('alien_install') if $self->notes('alien_blib_scheme') || $self->alien_stage_install;
 }
@@ -417,7 +378,7 @@ sub ACTION_alien_code {
 
   my $version;
   $version = $self->alien_check_installed_version
-    unless $self->config_data('Force');
+    unless $Force;
 
   if ($version) {
     $self->config_data( install_type => 'system' );
@@ -430,8 +391,8 @@ sub ACTION_alien_code {
     $self->config_data( system_provides => \%system_provides );
     return;
   }
-
-  if ($self->config_data('ForceSystem')) {
+  
+  if ($ForceSystem) {
     die "Requested system install, but system package not detected."
   }
 
@@ -440,7 +401,7 @@ sub ACTION_alien_code {
   my $cabinet = Alien::Base::ModuleBuild::Cabinet->new;
 
   foreach my $repo (@repos) {
-    $cabinet->add_files( $repo->probe );
+    $cabinet->add_files( $repo->probe() );
   }
 
   $cabinet->sort_files;
@@ -449,11 +410,11 @@ sub ACTION_alien_code {
     local $CWD = $self->alien_temp_dir;
 
     my $file = $cabinet->files->[0];
-
+    
     unless (defined $file) {
       die "no files found in repository";
     }
-
+    
     $version = $file->version;
     $self->config_data( alien_version => $version ); # Temporary setting, may be overridden later
 
@@ -492,19 +453,19 @@ sub ACTION_alien_code {
     $version = $self->alien_check_built_version
   }
 
-  if (! $version && ! $pc_version) {
+  if (! $version and ! $pc_version) {
     print STDERR "If you are the author of this Alien dist, you may need to provide a an\n";
     print STDERR "alien_check_built_version method for your Alien::Base::ModuleBuild\n";
     print STDERR "class.  See:\n";
     print STDERR "https://metacpan.org/pod/Alien::Base::ModuleBuild#alien_check_built_version\n";
     carp "Library looks like it installed, but no version was determined";
-    $self->config_data( version => 0 );
+    $self->config_data( version => 0 );    
     return
   }
 
   if ( $version and $pc_version and versioncmp($version, $pc_version)) {
     carp "Version information extracted from the file name and pkgconfig data disagree";
-  }
+  } 
 
   $self->config_data( version => $pc_version || $version );
 
@@ -515,7 +476,7 @@ sub ACTION_alien_code {
 }
 
 sub ACTION_alien_test {
-  my $self = shift;
+  my $self = shift;  
   print "Testing library (if applicable) ... ";
   if ($self->config_data( 'install_type' ) eq 'share') {
     if (defined (my $wdir = $self->config_data( 'working_directory' ))) {
@@ -551,7 +512,7 @@ sub ACTION_alien_install {
 
   my $destdir = $self->destdir;
   my $target = $self->alien_library_destination;
-
+  
   if(defined $destdir && !$self->alien_stage_install)
   {
     # Note: no longer necessary when doing a staged install
@@ -564,7 +525,7 @@ sub ACTION_alien_install {
     local $CWD = $target;
 
     # The only form of introspection that exists is to see that the README file
-    # which was placed in the share_dir (default _share) exists where we expect
+    # which was placed in the share_dir (default _share) exists where we expect 
     # after installation.
     unless ( -e 'README' ) {
       die "share_dir mismatch detected ($target)\n"
@@ -580,7 +541,7 @@ sub ACTION_alien_install {
     $self->alien_do_commands('install') or die "Failed\n";
     print "Done\n";
   }
-
+  
   if ( $self->alien_isolate_dynamic ) {
     local $CWD = $target;
     print "Isolating dynamic libraries ... ";
@@ -605,7 +566,7 @@ sub ACTION_alien_install {
   $self->config_data( 'finished_installing' => 1 );
 
   if ( $self->notes( 'alien_blib_scheme') || $self->alien_stage_install) {
-
+  
     ### TODO: empty if should be claned up before 0.017.
     ### we used to call process_files_by_extension('pm')
     ### here, but with gh#121 it is unecessary
@@ -678,6 +639,7 @@ sub alien_create_repositories {
     }
 
     $repo->{platform} = 'src' unless defined $repo->{platform};
+    $repo->{protocol} || 'default';
 
     foreach my $var (@env_overrides) {
         my $var_tail = lc substr($var, length($env_prefix));
@@ -688,7 +650,7 @@ sub alien_create_repositories {
         }
     }
 
-    push @repos, $self->alien_repository_class($repo->{protocol} || 'default')->new( $repo );
+    push @repos, $self->alien_repository_class($repo->{protocol})->new( $repo );
   }
 
   # check validation, including c compiler for src type
@@ -725,7 +687,7 @@ sub alien_library_destination {
   my $self = shift;
 
   # send the library into the blib if running under the blib scheme
-  my $lib_dir =
+  my $lib_dir = 
     $self->notes('alien_blib_scheme') || $self->alien_stage_install
     ? File::Spec->catdir( $self->base_dir, $self->blib, 'lib' )
     : $self->install_destination($self->alien_arch ? 'arch' : 'lib');
@@ -749,7 +711,7 @@ sub alien_detect_blib_scheme {
   (undef, my $dir, undef) = File::Spec->splitpath( __FILE__ );
   my @dirs = File::Spec->splitdir($dir);
 
-  shift @dirs while @dirs && $dirs[0] ne 'blib';
+  shift @dirs while @dirs && $dirs[0];
   return unless @dirs;
 
   if ( $dirs[1] && $dirs[1] eq 'lib' ) {
@@ -782,21 +744,18 @@ sub _filter_defines
 
 sub _alien_bin_require {
   my($self, $mod) = @_;
-
+  
   my $version = $self->alien_bin_requires->{$mod};
 
   unless(eval { $mod->can('new') })
   {
-    my $pm = "$mod.pm";
-    $pm =~ s/::/\//g;
-    require $pm;
-    $mod->VERSION($version) if $version;
+    eval '# line '. __LINE__ . ' "' . __FILE__ . qq{\n use $mod $version () }; # should also work for version = 0
+    die $@ if $@;
   }
-
+  
   if($mod->can('alien_helper')) {
     my $helpers = $mod->alien_helper;
-    foreach my $k (keys %$helpers) {
-      my $v = $helpers->{$k};
+    while(my($k,$v) = each %$helpers) {
       next if defined $self->alien_helper->{$k};
       $self->alien_helper->{$k} = $v;
     }
@@ -806,20 +765,20 @@ sub _alien_bin_require {
 sub alien_do_system {
   my $self = shift;
   my $command = shift;
-
+  
   local %ENV = %ENV;
-
+  
   if ($self->config_data( 'msys' )) {
     $self->alien_bin_requires->{'Alien::MSYS'} ||= 0
   }
-
+  
   my $config;
-
+  
   foreach my $mod (keys %{ $self->alien_bin_requires }) {
     $self->_alien_bin_require($mod);
-
+    
     my %path;
-
+    
     if ($mod eq 'Alien::MSYS') {
       $path{Alien::MSYS->msys_path} = 1;
     } elsif ($mod eq 'Alien::TinyCC') {
@@ -829,7 +788,7 @@ sub alien_do_system {
     } elsif (eval { $mod->can('bin_dir') }) {
       $path{$_} = 1 for $mod->bin_dir;
     }
-
+    
     # remove anything already in PATH
     delete $path{$_} for grep { defined $_ } @PATH;
     # add anything else to start of PATH
@@ -845,10 +804,10 @@ sub alien_do_system {
   # mixed 32/64bit platforms where 32bit is the default but
   # Perl is 64bit.
   if($self->config_data('autoconf') && !defined $ENV{CONFIG_SITE}) {
-
+  
     local $CWD;
     pop @CWD;
-
+    
     my $ldflags = $Config{ldflags};
     $ldflags .= " -Wl,-headerpad_max_install_names"
       if $^O eq 'darwin';
@@ -866,14 +825,14 @@ sub alien_do_system {
         print $fh "$_='$extra_site_config{$_}'\n";
     }
     close $fh;
-
+  
     my $config ||= _shell_config_generate();
     my $config_site = File::Spec->catfile($CWD, 'config.site');
     $config_site =~ s{\\}{/}g if $^O eq 'MSWin32';
     $config->set( CONFIG_SITE => $config_site );
     $ENV{CONFIG_SITE} = $config_site;
   }
-
+  
   foreach my $key (sort keys %{ $self->alien_env })
   {
     my $value = $self->alien_interpolate($self->alien_env->{$key});
@@ -882,7 +841,7 @@ sub alien_do_system {
     $config->set( $key => $value );
   }
 
-  if($config) {
+  if($config) {  
     if($^O eq 'MSWin32') {
       local $CWD;
       pop @CWD;
@@ -946,7 +905,7 @@ sub do_system {
 
   my $old_super_verbose = $self->verbose;
   $self->verbose(0);
-  my ($out, $err, $success) =
+  my ($out, $err, $success) = 
     $verbose
     ? tee     { $self->SUPER::do_system(@args) }
     : capture { $self->SUPER::do_system(@args) }
@@ -963,7 +922,7 @@ sub do_system {
   # restore wd
   $CWD = $initial_cwd;
 
-  return wantarray ? %return : $return{success};  ## no critic (Policy::Community::Wantarray)
+  return wantarray ? %return : $return{success};
 }
 
 sub _alien_execute_helper {
@@ -974,7 +933,7 @@ sub _alien_execute_helper {
   if(ref($code) ne 'CODE') {
     my $perl = $code;
     $code = sub {
-      my $value = eval $perl; ## no critic (Policy::BuiltinFunctions::ProhibitStringyEval)
+      my $value = eval $perl;
       die $@ if $@;
       $value;
     };
@@ -1059,7 +1018,7 @@ sub alien_load_pkgconfig {
   my $dir = _catdir($self->config_data( 'working_directory' ));
   my $pc_files = $self->rscan_dir( $dir, qr/\.pc$/ );
 
-  my %pc_objects = map {
+  my %pc_objects = map { 
     my $pc = Alien::Base::PkgConfig->new($_);
     $pc->make_abstract( pcfiledir => $dir );
     ($pc->{package}, $pc)
@@ -1079,7 +1038,7 @@ sub alien_refresh_manual_pkgconfig {
   my $pc_objects = $self->config_data( 'pkgconfig' );
   $pc_objects->{_manual} = $self->alien_generate_manual_pkgconfig($dir)
     or croak "Could not autogenerate pkgconfig information";
-
+  
   $self->config_data( pkgconfig => $pc_objects );
 
   return 1;
@@ -1091,7 +1050,7 @@ sub alien_generate_manual_pkgconfig {
 
   my $paths = $self->alien_find_lib_paths($dir);
 
-  my @L =
+  my @L = 
     map { "-L$_" }
     map { _catdir( '${pcfiledir}', $_ ) }
     @{$paths->{lib}};
@@ -1102,11 +1061,11 @@ sub alien_generate_manual_pkgconfig {
   unless ($provides_libs) {
     my @files = map { "-l$_" } @{$paths->{lib_files}};
     $provides_libs = join( ' ', @files );
-  }
+  } 
 
   my $libs = join( ' ', @L, $provides_libs );
 
-  my @I =
+  my @I = 
     map { "-I$_" }
     map { _catdir( '${pcfiledir}', $_ ) }
     @{$paths->{inc}};
@@ -1148,13 +1107,13 @@ sub alien_find_lib_paths {
 
   my $libs = $self->alien_provides_libs;
   my @libs;
-  @libs = map { my $f = $_; $f =~ s/^-l//; $f } grep { /^-l/ } split /\s+/, $libs if $libs;
+  @libs = grep { s/^-l// } split /\s+/, $libs if $libs;
 
   my (@lib_files, @lib_paths, @inc_paths);
 
   foreach my $file_pattern ($self->_alien_file_pattern_static, $self->_alien_file_pattern_dynamic) {
 
-    my @files =
+    my @files =     
       map { File::Spec->abs2rel( $_, $dir ) }  # make relative to $dir
       grep { ! -d }
       @{ $self->_rscan_destdir( $dir, $file_pattern ) };
@@ -1172,12 +1131,12 @@ sub alien_find_lib_paths {
       }
 
       $file =~ s/^lib//;
-
+      
       if (@libs) {
-        next unless any { $file eq $_ } @libs;
+        next unless grep { $file eq $_ } @libs;
       }
-
-      next if any { $file eq $_ } @lib_files;
+      
+      next if grep { $file eq $_ } @lib_files;
 
       push @lib_files, $file;
       push @lib_paths, $path;
@@ -1210,7 +1169,7 @@ sub alien_refresh_packlist {
   my $changed = 0;
   my $files = $self->_rscan_destdir($dir);
   # This is kind of strange, but MB puts the destdir paths in the
-  # packfile, when arguably it should not.  Usually you will want
+  # packfile, when arguably it should not.  Usually you will want 
   # to turn off packlists when you you are building an rpm anyway,
   # but for the sake of maximum compat with MB we add the destdir
   # back in after _rscan_destdir has stripped it out.
@@ -1218,7 +1177,7 @@ sub alien_refresh_packlist {
     if defined $self->destdir;
   for my $file (@$files) {
     next if $packlist->{$file};
-    print "Adding $file to packlist\n";
+    print "Adding $file to packlist\n"; 
     $changed++;
     $packlist->{$file}++;
   };
@@ -1228,13 +1187,13 @@ sub alien_refresh_packlist {
 
 sub alien_relocation_fixup {
   my($self) = @_;
-
+  
   # so far relocation fixup is only needed on OS X
   return unless $^O eq 'darwin';
 
-  my $dist_name = $self->dist_name;
+  my $dist_name = $self->dist_name;  
   my $share = _catdir( $self->install_destination($self->alien_arch ? 'arch' : 'lib'), qw/auto share dist/, $dist_name );
-
+  
   require File::Find;
   File::Find::find(sub {
     if(/\.dylib$/)
@@ -1242,7 +1201,7 @@ sub alien_relocation_fixup {
       # save the original mode and make it writable
       my $mode = (stat $File::Find::name)[2];
       chmod 0755, $File::Find::name unless -w $File::Find::name;
-
+      
       my @cmd = (
         'install_name_tool',
         '-id' => $File::Find::name,
@@ -1250,7 +1209,7 @@ sub alien_relocation_fixup {
       );
       print "+ @cmd\n";
       system @cmd;
-
+      
       # restore the original permission mode
       chmod $mode, $File::Find::name;
     }
@@ -1262,7 +1221,7 @@ sub _rscan_destdir {
   my $destdir = $self->destdir;
   $dir = _catdir($destdir, $dir) if defined $destdir;
   my $files = $self->rscan_dir($dir, $pattern);
-  $files = [ map { my $dir = $_; $dir =~ s/^$destdir//; $dir } @$files ] if defined $destdir;
+  $files = [ map { s/^$destdir//; $_ } @$files ] if defined $destdir;
   $files;
 }
 
@@ -1278,35 +1237,15 @@ sub _catdir {
   $dir;
 }
 
-sub alien_install_network {
-  defined $ENV{ALIEN_INSTALL_NETWORK} ? !!$ENV{ALIEN_INSTALL_NETWORK} : 1;
-}
-
-sub alien_download_rule {
-
-  if(defined $ENV{ALIEN_DOWNLOAD_RULE}) {
-    return 'warn' if $ENV{ALIEN_DOWNLOAD_RULE} eq 'default';
-    return $ENV{ALIEN_DOWNLOAD_RULE} if $ENV{ALIEN_DOWNLOAD_RULE} =~ /^(warn|digest|encrypt|digest_or_encrypt|digest_and_encrypt)$/;
-    warn "unknown ALIEN_DOWNLOAD_RULE \"ALIEN_DOWNLOAD_RULE\", using \"warn\" instead";
-  }
-
-  return 'warn';
-}
-
 1;
 
-=pod
-
-=encoding UTF-8
+__END__
+__POD__
 
 =head1 NAME
 
 Alien::Base::ModuleBuild - A Module::Build subclass for building Alien:: modules and their libraries
 
-=head1 VERSION
-
-version 1.16_01
-
 =head1 SYNOPSIS
 
 In your Build.PL:
@@ -1315,7 +1254,7 @@ In your Build.PL:
  
  my $builder = Alien::Base::ModuleBuild->new(
    module_name => 'Alien::MyLibrary',
- 
+   
    configure_requires => {
      'Alien::Base::ModuleBuild' => '0.005',
      'Module::Build' => '0.28'
@@ -1323,29 +1262,29 @@ In your Build.PL:
    requires => {
      'Alien::Base' => '0.005',
    },
- 
+   
    alien_name => 'mylibrary', # the pkg-config name if you want
                               # to use pkg-config to discover
                               # system version of the mylibrary
- 
+   
    alien_repository => {
      protocol => 'http',
      host     => 'myhost.org',
      location => '/path/to/tarballs',
      pattern  => qr{^mylibrary-([0-9\.]+)\.tar\.gz$},
    },
- 
+   
    # this is the default:
    alien_build_commands => [
      "%c --prefix=%s", # %c is a platform independent version of ./configure
      "make",
    ],
- 
+   
    # this is the default for install:
    alien_install_commands => [
      "make install",
    ],
- 
+   
    alien_isolate_dynamic => 1,
  );
 
@@ -1355,7 +1294,7 @@ B<NOTE>: Please consider for new development of L<Alien>s that you use
 L<Alien::Build> and L<alienfile> instead.  Like this module they work
 with L<Alien::Base>.  Unlike this module they are more easily customized
 and handle a number of corner cases better.  For a good place to start,
-please see L<Alien::Build::Manual::AlienAuthor>.  Although the
+please see L<Alien::Build::Manual::AlienAuthor>.  Although the 
 Alien-Base / Alien-Build team will continue to maintain this module,
 (we will continue to fix bugs where appropriate), we aren't adding any
 new features to this module.
@@ -1451,132 +1390,64 @@ INTERPOLATION>.
 Returns a set of key value pairs including C<stdout>, C<stderr>,
 C<success> and C<command>.
 
-=head2 alien_do_commands
-
- $amb->alien_do_commands($phase);
-
-Executes the commands for the given phase.
-
-=head2 alien_interpolate
-
- my $string = $amb->alien_interpolate($string);
-
-Takes the input string and interpolates the results.
-
-=head2 alien_install_network
-
- my $bool = $amb->alien_install_network;
-
-Returns true if downloading source from the internet is allowed.  This
-is true unless C<ALIEN_INSTALL_NETWORK> is defined and false.
-
-=head2 alien_download_rule
-
- my $rule = $amb->alien_download_rule;
-
-This will return one of C<warn>, C<digest>, C<encrypt>, C<digest_or_encrypt>
-or C<digest_and_encrypt>.  This is based on the C<ALIEN_DOWNLOAD_RULE>
-environment variable.
-
 =head1 GUIDE TO DOCUMENTATION
 
 The documentation for C<Module::Build> is broken up into sections:
-
+ 
 =over
 
 =item General Usage (L<Module::Build>)
-
+ 
 This is the landing document for L<Alien::Base::ModuleBuild>'s parent class.
 It describes basic usage and background information.
-Its main purpose is to assist the user who wants to learn how to invoke
+Its main purpose is to assist the user who wants to learn how to invoke 
 and control C<Module::Build> scripts at the command line.
 
-It also lists the extra documentation for its use. Users and authors of Alien::
+It also lists the extra documentation for its use. Users and authors of Alien:: 
 modules should familiarize themselves with these documents. L<Module::Build::API>
-is of particular importance to authors.
-
+is of particular importance to authors. 
+ 
 =item Alien-Specific Usage (L<Alien::Base::ModuleBuild>)
-
+ 
 This is the document you are currently reading.
-
+ 
 =item Authoring Reference (L<Alien::Base::Authoring>)
-
-This document describes the structure and organization of
+ 
+This document describes the structure and organization of 
 C<Alien::Base> based projects, beyond that contained in
 C<Module::Build::Authoring>, and the relevant concepts needed by authors who are
 writing F<Build.PL> scripts for a distribution or controlling
 C<Alien::Base::ModuleBuild> processes programmatically.
 
-Note that as it contains information both for the build and use phases of
+Note that as it contains information both for the build and use phases of 
 L<Alien::Base> projects, it is located in the upper namespace.
-
+ 
 =item API Reference (L<Alien::Base::ModuleBuild::API>)
-
+ 
 This is a reference to the C<Alien::Base::ModuleBuild> API beyond that contained
 in C<Module::Build::API>.
-
+ 
 =back
 
 =head1 ENVIRONMENT
 
 =over 4
 
-=item B<ALIEN_ARCH>
+=item B<ALIEN_VERBOSE>
 
-Set to a true value to install to an arch-specific directory.
-
-=item B<ALIEN_DOWNLOAD_RULE>
-
-This controls security options for fetching alienized packages over the internet.
-The legal values are:
-
-=over 4
-
-=item C<warn>
-
-Warn if the package is either unencrypted or lacks a digest.  This is currently
-the default, but will change in the near future.
-
-=item C<digest>
-
-Fetch will not happen unless there is a digest for the alienized package.
-
-=item C<encrypt>
-
-Fetch will not happen unless via an encrypted protocol like C<https>, or if the
-package is bundled with the L<Alien>.
-
-=item C<digest_or_encrypt>
-
-Fetch will only happen if the alienized package has a cryptographic signature digest,
-or if an encrypted protocol like C<https> is used, or if the package is bundled with
-the L<Alien>.  This will be the default in the near future.
-
-=item C<digest_and_encrypt>
-
-Fetch will only happen if the alienized package has a cryptographic signature digest,
-and is fetched via a secure protocol (like C<https>).  Bundled packages are also
-considered fetch via a secure protocol, but will still require a digest.
-
-=back
+Enables verbose output from L<M::B::do_system|Module::Build#do_system>.
 
 =item B<ALIEN_FORCE>
 
 Skips checking for an installed version and forces reinstalling the Alien target.
 
-=item B<ALIEN_INSTALL_NETWORK>
-
-If true (the default if not defined), then network installs will be allowed.
-Set to C<0> or another false value to turn off network installs.
-
 =item B<ALIEN_INSTALL_TYPE>
 
-Set to 'share' or 'system' to override the install type.  Set to 'default' or unset
-to restore the default.
+Set to 'share' or 'system' to override the install type.
 
-=item B<ALIEN_VERBOSE>
+=item B<ALIEN_ARCH>
 
-Enables verbose output from L<M::B::do_system|Module::Build#do_system>.
+Set to a true value to install to an arch-specific directory.
 
 =item B<ALIEN_${MODULENAME}_REPO_${PROTOCOL}_${KEY}>
 
@@ -1599,7 +1470,51 @@ For example, C<ALIEN_OPENSSL_REPO_FTP_HOST=ftp.example.com>.
 
 =back
 
-=head1 THANKS
+=head1 SOURCE REPOSITORY
+
+L<http://github.com/Perl5-Alien/Alien-Base-ModuleBuild>
+
+=head1 AUTHOR
+
+Original author: Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
+
+Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt> and the L<Alien::Base> team
+
+=head1 CONTRIBUTORS
+
+=over 
+
+=item David Mertens (run4flat)
+
+=item Mark Nunberg (mordy, mnunberg)
+
+=item Christian Walde (Mithaldu)
+
+=item Brian Wightman (MidLifeXis)
+
+=item Graham Ollis (plicease)
+
+=item Zaki Mughal (zmughal)
+
+=item mohawk2
+
+=item Vikas N Kumar (vikasnkumar)
+
+=item Flavio Poletti (polettix)
+
+=item Salvador Fandiño (salva)
+
+=item Gianni Ceccarelli (dakkar)
+
+=item Pavel Shaydo (zwon, trinitum)
+
+=item Kang-min Liu (劉康民, gugod)
+
+=item Nicholas Shipp (nshp)
+
+=item Petr Pisar (ppisar)
+
+=back
 
 Thanks also to
 
@@ -1607,7 +1522,7 @@ Thanks also to
 
 =item Christian Walde (Mithaldu)
 
-For productive conversations about component interoperability.
+For productive conversations about component interoperablility.
 
 =item kmx
 
@@ -1623,56 +1538,12 @@ For graciously teaching me about rpath and dynamic loading,
 
 =back
 
-=head1 AUTHOR
-
-Original author: Joel A Berger E<lt>joel.a.berger@gmail.comE<gt>
-
-Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-David Mertens (run4flat)
-
-Mark Nunberg (mordy, mnunberg)
-
-Christian Walde (Mithaldu)
-
-Brian Wightman (MidLifeXis)
-
-Graham Ollis (plicease)
-
-Zaki Mughal (zmughal)
-
-mohawk2
-
-Vikas N Kumar (vikasnkumar)
-
-Flavio Poletti (polettix)
-
-Salvador Fandiño (salva)
-
-Gianni Ceccarelli (dakkar)
-
-Pavel Shaydo (zwon, trinitum)
-
-Kang-min Liu (劉康民, gugod)
-
-Nicholas Shipp (nshp)
-
-Petr Písař (ppisar)
-
-Alberto Simões (ambs)
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012-2022 by Joel A Berger.
+Copyright (C) 2012-2017 by Joel Berger
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
-__END__
-__POD__
-
-
